import pandas as pd

class JSONEncoder(object):
  # Encode using JSON, create a MultiEncoder with needed Encoder objects under the hood.
  pass